@@ -1,4 +1,4 @@
-"""Internal default handler for standard processes."""
+"""Default handler for standard processes."""
 
 from . import ProcessHandler
 from ...pane import Pane
